﻿using System;
using Ozeki.Media;
using Ozeki.VoIP;
using Ozeki.Camera;

namespace Video_call
{
    internal class Program
    {
        private static ISoftPhone softphone; // softphone object
        private static IPhoneLine phoneLine; // phoneline object
        private static IPhoneCall call;
        private static string numberToDial;
        private static MediaConnector mediaConnector;

        private static void Main(string[] args)
        {
            // Create a softphone object with RTP port range 5000-10000
            softphone = SoftPhoneFactory.CreateSoftPhone(5000, 10000);

            // SIP account registration data, (supplied by your VoIP service provider)
            var registrationRequired = true;
            var userName = "sipusername";
            var displayName = "sipdisplayname";
            var authenticationId = "authenticationid";
            var registerPassword = "Password";
            var domainHost = "pbxip.voipprovider.com";
            var domainPort = 5060;

            var account = new SIPAccount(registrationRequired, displayName, userName, authenticationId, registerPassword, domainHost, domainPort);

            // Send SIP regitration request
            RegisterAccount(account);

            // Prevents the termination of the application
            Console.ReadLine();
        }

        static void RegisterAccount(SIPAccount account)
        {
            try
            {
                phoneLine = softphone.CreatePhoneLine(account);
                phoneLine.RegistrationStateChanged += sipAccount_RegStateChanged;
                softphone.RegisterPhoneLine(phoneLine);
            }
            catch (Exception ex)
            {
                Console.WriteLine("Error during SIP registration: " + ex);
            }
        }

        private static void sipAccount_RegStateChanged(object sender, RegistrationStateChangedArgs e)
        {
            Console.WriteLine(e.State);
            if (e.State == RegState.RegistrationSucceeded)
                CreateCall();
        }

        static void CreateCall()
        {
            numberToDial = "1001";
            call = softphone.CreateCallObject(phoneLine, numberToDial);

            mediaConnector = new MediaConnector();
            var phoneCallVideoSender = new PhoneCallVideoSender();
            var cam = WebCameraFactory.GetDefaultDevice();

            if (cam != null)
            {
                cam.Start();
                mediaConnector.Connect(cam.VideoChannel, phoneCallVideoSender);
            }

            phoneCallVideoSender.AttachToCall(call);

            call.CallStateChanged += call_CallStateChanged;
            call.Start();
        }

        static void call_CallStateChanged(object sender, CallStateChangedArgs e)
        {
            Console.WriteLine("\nCall state: {0}.", e.State);
        }
    }  
}
